@@ -10,19 +10,23 @@ from selenium.webdriver.chrome.options import Options
 from .errors import AdsError
 from .configs import UserProxyConfig, FingepringConfig
 
+methods = {
+    'GET':requests.get,
+    'POST':requests.post
+}
 
 @dataclass
 class AdsApi:
     base_url_ads: str
     lock: Lock = mp.Lock()
 
-    def request(self, endpoint: str, params: dict | None = None, data: dict | None = None, attempts: int = 5):
+    def request(self, endpoint: str, params: dict | None = None, data: dict | None = None, attempts: int = 5, method:str = 'GET'):
         req_info = f'request {self.base_url_ads+endpoint}\n data = {data}\n params = {params}\n'
         for attempt in range(attempts):
             try:
                 self.lock.acquire()
                 sleep(1)  # because limite 1 request per second
-                response = requests.get(
+                response = methods[method](
                     self.base_url_ads + endpoint, params=params, data=data).json()
                 self.lock.release()
             except:
@@ -40,11 +44,11 @@ class AdsApi:
 
     def update_group(self, group_id: int, group_name: str) -> None:
         resp = self.request(
-            '/api/v1/group/update', data={'group_id': group_id, 'group_name': group_name})
+            '/api/v1/group/update', data={'group_id': group_id, 'group_name': group_name}, method='POST')
 
     def create_group(self, group_name: str) -> dict:
         resp = self.request('/api/v1/group/create',
-                            data={'group_name': group_name})
+                            data={'group_name': group_name}, method='POST')
         return resp
 
     def open_browser(self, user_id: str, serial_number: str | None = None,
@@ -74,7 +78,7 @@ class AdsApi:
                             data={'name': name, 'domain_name': domain_name, 'open_urls':open_urls, 'repeat_config':repeat_config, 'username':username,
                                     'password':password, 'cookie':cookie, 'ignore_cookie_error':ignore_cookie_error, 'group_id':group_id,
                                     'ip':ip, 'country':country, 'city':city, 'remark':remark, 'user_proxy_config':user_proxy_config,
-                                    'fingerprint_config':fingerprint_config})
+                                    'fingerprint_config':fingerprint_config}, method='POST')
         return resp
 
     def update_account(self, name: str, domain_name: int | None = None, open_urls: list[str] | None = None,
@@ -86,7 +90,7 @@ class AdsApi:
                             data={'name': name, 'domain_name': domain_name, 'open_urls':open_urls, 'repeat_config':repeat_config, 'username':username,
                                     'password':password, 'cookie':cookie, 'ignore_cookie_error':ignore_cookie_error, 'group_id':group_id,
                                     'ip':ip, 'country':country, 'city':city, 'remark':remark, 'user_proxy_config':user_proxy_config,
-                                    'fingerprint_config':fingerprint_config})
+                                    'fingerprint_config':fingerprint_config}, method='POST')
         return resp
 
     def query_account(self, group_id:int|None = None, user_id:str|None = None, serial_number:int|None = None, page:int=1, page_size:int = 1) -> list[dict]:
@@ -96,13 +100,13 @@ class AdsApi:
 
     def delete_account(self, user_ids:list[int]) -> dict:
         resp = self.request('/api/v1/user/delete',
-                            data={'user_ids': user_ids})
+                            data={'user_ids': user_ids}, method='POST')
         return resp
 
 
     def update_account_group(self, user_ids:list[int], group_id:int) -> dict:
         resp = self.request('/api/v1/user/regroup',
-                            data={'user_ids': user_ids, 'group_id':group_id})
+                            data={'user_ids': user_ids, 'group_id':group_id}, method='POST')
         return resp
 
 
